pub struct APIVersionResponse {
pub version: String,
}Fields
version: StringTrait Implementations
Sourceimpl Clone for APIVersionResponse
impl Clone for APIVersionResponse
Sourcefn clone(&self) -> APIVersionResponse
fn clone(&self) -> APIVersionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for APIVersionResponse
impl<'de> Deserialize<'de> for APIVersionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for APIVersionResponse
impl JsonSchema for APIVersionResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for APIVersionResponse
impl PartialEq for APIVersionResponse
Sourcefn eq(&self, other: &APIVersionResponse) -> bool
fn eq(&self, other: &APIVersionResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for APIVersionResponse
impl Serialize for APIVersionResponse
impl StructuralPartialEq for APIVersionResponse