pub struct AirdropResponse {
pub start: u64,
pub period: u64,
pub reward_token: String,
pub reward_rate: Decimal,
}Fields
start: u64period: u64reward_token: Stringreward_rate: DecimalTrait Implementations
Sourceimpl Clone for AirdropResponse
impl Clone for AirdropResponse
Sourcefn clone(&self) -> AirdropResponse
fn clone(&self) -> AirdropResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AirdropResponse
impl Debug for AirdropResponse
Sourceimpl<'de> Deserialize<'de> for AirdropResponse
impl<'de> Deserialize<'de> for AirdropResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AirdropResponse
impl JsonSchema for AirdropResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AirdropResponse
impl PartialEq for AirdropResponse
Sourcefn eq(&self, other: &AirdropResponse) -> bool
fn eq(&self, other: &AirdropResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AirdropResponse
impl Serialize for AirdropResponse
impl StructuralPartialEq for AirdropResponse