pub struct PollResponse {Show 14 fields
pub id: u64,
pub creator: String,
pub status: PollStatus,
pub end_height: u64,
pub title: String,
pub category: PollCategory,
pub description: String,
pub link: Option<String>,
pub deposit_amount: Uint128,
pub execute_data: Option<Vec<PollExecuteMsg>>,
pub yes_votes: Uint128,
pub no_votes: Uint128,
pub staked_amount: Option<Uint128>,
pub total_balance_at_end_poll: Option<Uint128>,
}Fields
id: u64creator: Stringstatus: PollStatusend_height: u64title: Stringcategory: PollCategorydescription: Stringlink: Option<String>deposit_amount: Uint128execute_data: Option<Vec<PollExecuteMsg>>yes_votes: Uint128no_votes: Uint128staked_amount: Option<Uint128>total_balance_at_end_poll: Option<Uint128>Trait Implementations
Sourceimpl Clone for PollResponse
impl Clone for PollResponse
Sourcefn clone(&self) -> PollResponse
fn clone(&self) -> PollResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PollResponse
impl Debug for PollResponse
Sourceimpl<'de> Deserialize<'de> for PollResponse
impl<'de> Deserialize<'de> for PollResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PollResponse
impl JsonSchema for PollResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PollResponse
impl PartialEq for PollResponse
Sourcefn eq(&self, other: &PollResponse) -> bool
fn eq(&self, other: &PollResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PollResponse
impl Serialize for PollResponse
impl StructuralPartialEq for PollResponse