pub struct StakerInfoResponse {
pub staker: String,
pub reward_index: Decimal,
pub bond_amount: Uint128,
pub pending_reward: Uint128,
}Fields
staker: Stringreward_index: Decimalbond_amount: Uint128pending_reward: Uint128Trait Implementations
Sourceimpl Clone for StakerInfoResponse
impl Clone for StakerInfoResponse
Sourcefn clone(&self) -> StakerInfoResponse
fn clone(&self) -> StakerInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StakerInfoResponse
impl Debug for StakerInfoResponse
Sourceimpl<'de> Deserialize<'de> for StakerInfoResponse
impl<'de> Deserialize<'de> for StakerInfoResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StakerInfoResponse
impl JsonSchema for StakerInfoResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StakerInfoResponse
impl PartialEq for StakerInfoResponse
Sourcefn eq(&self, other: &StakerInfoResponse) -> bool
fn eq(&self, other: &StakerInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StakerInfoResponse
impl Serialize for StakerInfoResponse
impl StructuralPartialEq for StakerInfoResponse