pub struct VestingAccount {
pub address: String,
pub schedules: Vec<(u64, u64, Uint128)>,
}Expand description
CONTRACT: end_time > start_time
Fields
address: Stringschedules: Vec<(u64, u64, Uint128)>Trait Implementations
Sourceimpl Clone for VestingAccount
impl Clone for VestingAccount
Sourcefn clone(&self) -> VestingAccount
fn clone(&self) -> VestingAccount
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VestingAccount
impl Debug for VestingAccount
Sourceimpl<'de> Deserialize<'de> for VestingAccount
impl<'de> Deserialize<'de> for VestingAccount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VestingAccount
impl JsonSchema for VestingAccount
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VestingAccount
impl PartialEq for VestingAccount
Sourcefn eq(&self, other: &VestingAccount) -> bool
fn eq(&self, other: &VestingAccount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VestingAccount
impl Serialize for VestingAccount
impl StructuralPartialEq for VestingAccount