pub struct VestingAccountResponse {
pub address: String,
pub info: VestingInfo,
}Fields
address: Stringinfo: VestingInfoTrait Implementations
Sourceimpl Clone for VestingAccountResponse
impl Clone for VestingAccountResponse
Sourcefn clone(&self) -> VestingAccountResponse
fn clone(&self) -> VestingAccountResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VestingAccountResponse
impl Debug for VestingAccountResponse
Sourceimpl<'de> Deserialize<'de> for VestingAccountResponse
impl<'de> Deserialize<'de> for VestingAccountResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VestingAccountResponse
impl JsonSchema for VestingAccountResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VestingAccountResponse
impl PartialEq for VestingAccountResponse
Sourcefn eq(&self, other: &VestingAccountResponse) -> bool
fn eq(&self, other: &VestingAccountResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VestingAccountResponse
impl Serialize for VestingAccountResponse
impl StructuralPartialEq for VestingAccountResponse