pub struct VestingInfo {
pub schedules: Vec<(u64, u64, Uint128)>,
pub last_claim_time: u64,
}Fields
schedules: Vec<(u64, u64, Uint128)>last_claim_time: u64Trait Implementations
Sourceimpl Clone for VestingInfo
impl Clone for VestingInfo
Sourcefn clone(&self) -> VestingInfo
fn clone(&self) -> VestingInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VestingInfo
impl Debug for VestingInfo
Sourceimpl<'de> Deserialize<'de> for VestingInfo
impl<'de> Deserialize<'de> for VestingInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VestingInfo
impl JsonSchema for VestingInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VestingInfo
impl PartialEq for VestingInfo
Sourcefn eq(&self, other: &VestingInfo) -> bool
fn eq(&self, other: &VestingInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VestingInfo
impl Serialize for VestingInfo
impl StructuralPartialEq for VestingInfo